==> htsct-0.0.22-py3-none-any.whl: htsct/constants/__init__.py <==
from pathlib import Path
from os.path import expanduser
from importlib.resources import open_text
from typing import Union
from toml import load
from typing.io import IO, TextIO
from pathlib import PurePath
from htsct import statics
import yaml

NameOrFile = Union[str, PurePath, IO]
HTS_HOME = Path(expanduser('~')) / "htsct"
STATIC_PATH = Path(statics.__path__[0])
# vasp path
VASP_STD = ""
VASP_NCL = ""
VASP_GAM = ""

# script path
QSUB = ""

# statics
HTS_STATICS = [
    "htsct.statics",  # 第一个为包名
    [".htsct.sub.sh",  # 资源文件名
     ".htsct.toml",
     "vasp input.yaml"
     ]
]
# OUTPUT
TASK_LOG = ""
FIGS_PATH = ""
DB_DIR = ""
WORK_PATH = ""
SYSTEM_LOG = HTS_HOME / "log.txt"
CALC_FILES = HTS_HOME / "calcs"

# vasp input
VASP_INPUT = None

# settings
WAIT_INTERVAL = 0  # 空闲等待时间


# load from files
def load_config(fd: TextIO):
    data = load(fd)
    config = {}
    for _ in data.values():
        config.update({k.upper(): v for k, v in _.items()})
    globals().update(config)


if not (HTS_HOME / ".htsct.toml").is_file():
    load_config(open_text(HTS_STATICS[0], ".htsct.toml"))
else:
    with open(HTS_HOME / ".htsct.toml") as fd:
        load_config(fd)

if not (HTS_HOME / ".htsct.sub.sh").is_file():
    QSUB = STATIC_PATH / ".htsct.sub.sh"

if not (HTS_HOME / "vasp input.yaml").is_file():
    with open(STATIC_PATH / "vasp input.yaml") as fd:
        VASP_INPUT = yaml.load(fd, Loader=yaml.FullLoader)
else:
    with open(HTS_HOME / "vasp input.yaml") as fd:
        VASP_INPUT = yaml.load(fd, Loader=yaml.FullLoader)

==> htsct-0.0.27-py3-none-any.whl: htsct/constants/__init__.py <==
from pathlib import Path
from os.path import expanduser
from importlib.resources import open_text
from typing import Union
from toml import load
from typing import IO, TextIO
from pathlib import PurePath
from htsct import statics
import yaml

NameOrFile = Union[str, PurePath, IO]
HTS_HOME = Path(expanduser('~')) / "htsct"
STATIC_PATH = Path(statics.__path__[0])
# vasp path
VASP_STD = ""
VASP_NCL = ""
VASP_GAM = ""

# script path
QSUB = ""

# statics
HTS_STATICS = [
    "htsct.statics",  # 第一个为包名
    [".htsct.sub.sh",  # 资源文件名
     ".htsct.toml",
     "vasp input.yaml"
     ]
]
# OUTPUT
TASK_LOG = ""
FIGS_PATH = ""
DB_DIR = ""
WORK_PATH = ""
SYSTEM_LOG = HTS_HOME / "log.txt"
CALC_FILES = HTS_HOME / "calcs"

# vasp input
VASP_INPUT = None

# settings
WAIT_INTERVAL = 0  # 空闲等待时间
INPUT_FILE_TYPE = ""


# load from files
def load_config(fd: TextIO):
    data = load(fd)
    config = {}
    for _ in data.values():
        config.update({k.upper(): v for k, v in _.items()})
    globals().update(config)


if not (HTS_HOME / ".htsct.toml").is_file():
    load_config(open_text(HTS_STATICS[0], ".htsct.toml"))
else:
    with open(HTS_HOME / ".htsct.toml") as fd:
        load_config(fd)

if not (HTS_HOME / ".htsct.sub.sh").is_file():
    QSUB = STATIC_PATH / ".htsct.sub.sh"

if not (HTS_HOME / "vasp input.yaml").is_file():
    with open(STATIC_PATH / "vasp input.yaml") as fd:
        VASP_INPUT = yaml.load(fd, Loader=yaml.FullLoader)
else:
    with open(HTS_HOME / "vasp input.yaml") as fd:
        VASP_INPUT = yaml.load(fd, Loader=yaml.FullLoader)

if not (HTS_HOME / ".guiConfig.toml").is_file():
    GUI_CONFIG = STATIC_PATH / ".guiConfig.toml"
else:
    GUI_CONFIG = HTS_HOME / ".guiConfig.toml"
